# Owl2diagram

## How to run locally
```
python 
```

## How to use

1. Clone the Owl2diagram repository

   `git clone https://github.com/jatoledo/owl2diagram.git`

2. Run the docker image with docker-compose

   `docker-compose up -d`

3. Starting server at http://127.0.0.1:8000/

## Example

Submit ontology URL.

![](https://raw.githubusercontent.com/jatoledo/owl2diagram/main/images/image1.png)

Result:

![](https://raw.githubusercontent.com/jatoledo/owl2diagram/main/images/image2.png)

## Version

```
0.1.0
```

## Authors

- Jhon Toledo.
